@@ -1,7 +1,16 @@
+import base64
+import os
+import pickle
 import subprocess
+from collections.abc import Callable
+from pathlib import Path
 from urllib.parse import urlencode
+from typing import ParamSpec
 
-from .base import PLUGIN_PATH
+PLUGIN_PATH = Path(os.environ.get('SWIFTBAR_PLUGIN_PATH', '.'))
+
+
+P = ParamSpec('P')
 
 
 def open_callback_url(scheme: str, path: str, **params: str | int | None) -> None:
@@ -33,3 +42,17 @@ def toggleplugin() -> None:
 
 def notify(**params: str | int | None) -> None:
     open_callback_url('swiftbar', 'notify', name=PLUGIN_PATH.name, **params)
+
+
+def serialize_callback(callback: Callable[P, object], *args: P.args, **kwargs: P.kwargs) -> str:
+    cb_byt = pickle.dumps((callback, args, kwargs))
+    cb_b64 = base64.b64encode(cb_byt)
+    cb_txt = cb_b64.decode('ascii')
+    return cb_txt
+
+
+def deserialize_callback(cb_txt: str) -> tuple[Callable[P, object], P.args, P.kwargs]:
+    cb_b64 = cb_txt.encode('ascii')
+    cb_byt = base64.b64decode(cb_b64)
+    callback, args, kwargs = pickle.loads(cb_byt)
+    return callback, args, kwargs
